summaryrefslogtreecommitdiffstats
path: root/src/base/Composition.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/base/Composition.h')
-rw-r--r--src/base/Composition.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/base/Composition.h b/src/base/Composition.h
index 5a1b0ac..b2f80a3 100644
--- a/src/base/Composition.h
+++ b/src/base/Composition.h
@@ -254,7 +254,7 @@ public:
/**
* Test whether a Segment exists in this Composition.
*/
- bool tqcontains(const Segment *);
+ bool contains(const Segment *);
/**
* Return an iterator pointing at the given Segment, or end()
@@ -437,7 +437,7 @@ public:
}
/**
* Return the starting and ending times of the bar that tqcontains
* time t.
*
* Will happily return theoretical timings for bars before the
@@ -906,7 +906,7 @@ protected:
std::string getEventType() const { return m_eventType; }
private:
- iterator tqfind(Event *e);
+ iterator find(Event *e);
std::string m_eventType;
};
@@ -437,7 +437,7 @@ public:
}
/**
- * Return the starting and ending times of the bar that tqcontains
+ * Return the starting and ending times of the bar that contains
* time t.
*